@@ -20,6 +20,9 @@ class Rackspace(BaseCloud):
     PROVIDER_NAME = 'RACKSPACE' 
 
     def deploy(self, image_id, size_idx=0, location_idx=0, name='test'):
+        """Rackspace supports libcloud's `libcloud.compute.deployment`.
+
+        Pass an `SSHKeyDeployment` to `self.driver.deploy_node`."""
         sd = SSHKeyDeployment(open(self.ssh_public_key).read())
         script = ScriptDeployment("/bin/true") # NOP
         msd = MultiStepDeployment([sd, script])
